Index: base/trace_event/trace_config.cc |
diff --git a/base/trace_event/trace_config.cc b/base/trace_event/trace_config.cc |
index 7124bea8bf6a1cb0ea1a4bbbf29dfc4b52287c6c..e15d274f18e85b620a69ad662b896f27127b16c5 100644 |
--- a/base/trace_event/trace_config.cc |
+++ b/base/trace_event/trace_config.cc |
@@ -209,9 +209,13 @@ bool TraceConfig::IsCategoryGroupEnabled( |
break; |
} |
// One of the category of category_group_name is not present in |
- // excluded_ list. So, it has to be included_ list. Enable the |
- // category_group_name for recording. |
- category_group_disabled = false; |
+ // excluded_ list. So, if it's not a disabled-by-default category, |
+ // it has to be included_ list. Enable the category_group_name |
+ // for recording. |
+ if (!base::MatchPattern(category_group_token.c_str(), |
+ TRACE_DISABLED_BY_DEFAULT("*"))) { |
+ category_group_disabled = false; |
+ } |
} |
// One of the categories present in category_group_name is not present in |
// excluded_ list. Implies this category_group_name group can be enabled |